summaryrefslogtreecommitdiffstats
path: root/libkgpgfile/kgpgfile.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'libkgpgfile/kgpgfile.cpp')
-rw-r--r--libkgpgfile/kgpgfile.cpp30
1 files changed, 15 insertions, 15 deletions
diff --git a/libkgpgfile/kgpgfile.cpp b/libkgpgfile/kgpgfile.cpp
index 0cf449f..50f65bd 100644
--- a/libkgpgfile/kgpgfile.cpp
+++ b/libkgpgfile/kgpgfile.cpp
@@ -225,7 +225,7 @@ bool KGPGFile::open(int mode, const TQString& cmdArgs, bool skipPasswd)
bool KGPGFile::startProcess(const TQStringList& args)
{
// now start the KProcess with GPG
m_process = new KShellProcess();
*m_process << "gpg";
*m_process << args;
@@ -233,19 +233,19 @@ bool KGPGFile::startProcess(const TQStringList& args)
// TQString arglist = args.join(":");
// tqDebug("gpg '%s'", arglist.data());
- connect(m_process, TQT_SIGNAL(processExited(KProcess *)),
- this, TQT_SLOT(slotGPGExited(KProcess *)));
+ connect(m_process, TQT_SIGNAL(processExited(TDEProcess *)),
+ this, TQT_SLOT(slotGPGExited(TDEProcess *)));
- connect(m_process, TQT_SIGNAL(receivedStdout(KProcess*, char*, int)),
- this, TQT_SLOT(slotDataFromGPG(KProcess*, char*, int)));
+ connect(m_process, TQT_SIGNAL(receivedStdout(TDEProcess*, char*, int)),
+ this, TQT_SLOT(slotDataFromGPG(TDEProcess*, char*, int)));
- connect(m_process, TQT_SIGNAL(receivedStderr(KProcess*, char*, int)),
- this, TQT_SLOT(slotErrorFromGPG(KProcess*, char*, int)));
+ connect(m_process, TQT_SIGNAL(receivedStderr(TDEProcess*, char*, int)),
+ this, TQT_SLOT(slotErrorFromGPG(TDEProcess*, char*, int)));
- connect(m_process, TQT_SIGNAL(wroteStdin(KProcess *)),
- this, TQT_SLOT(slotSendDataToGPG(KProcess *)));
+ connect(m_process, TQT_SIGNAL(wroteStdin(TDEProcess *)),
+ this, TQT_SLOT(slotSendDataToGPG(TDEProcess *)));
- if(!m_process->start(KProcess::NotifyOnExit, (KProcess::Communication)(KProcess::Stdin|KProcess::Stdout|KProcess::Stderr))) {
+ if(!m_process->start(TDEProcess::NotifyOnExit, (TDEProcess::Communication)(TDEProcess::Stdin|TDEProcess::Stdout|TDEProcess::Stderr))) {
// tqDebug("m_process->start failed");
delete m_process;
m_process = 0;
@@ -265,7 +265,7 @@ void KGPGFile::close(void)
return;
}
// finish the KProcess and clean up things
if(m_process) {
if(isWritable()) {
// tqDebug("Finish writing");
@@ -437,7 +437,7 @@ TQByteArray KGPGFile::readAll(void)
return ba;
}
-void KGPGFile::slotGPGExited(KProcess* )
+void KGPGFile::slotGPGExited(TDEProcess* )
{
// tqDebug("GPG finished");
if(m_process) {
@@ -458,7 +458,7 @@ void KGPGFile::slotGPGExited(KProcess* )
}
}
-void KGPGFile::slotDataFromGPG(KProcess* proc, char* buf, int len)
+void KGPGFile::slotDataFromGPG(TDEProcess* proc, char* buf, int len)
{
// tqDebug("Received %d bytes on stdout", len);
@@ -490,7 +490,7 @@ void KGPGFile::slotDataFromGPG(KProcess* proc, char* buf, int len)
// tqDebug("end slotDataFromGPG");
}
-void KGPGFile::slotErrorFromGPG(KProcess *, char *buf, int len)
+void KGPGFile::slotErrorFromGPG(TDEProcess *, char *buf, int len)
{
// tqDebug("Received %d bytes on stderr", len);
TQCString msg;
@@ -499,7 +499,7 @@ void KGPGFile::slotErrorFromGPG(KProcess *, char *buf, int len)
msg.resetRawData(buf, len);
}
-void KGPGFile::slotSendDataToGPG(KProcess *)
+void KGPGFile::slotSendDataToGPG(TDEProcess *)
{
// tqDebug("wrote stdin");
if(m_needExitLoop) {
@@ -225,7 +225,7 @@ bool KGPGFile::open(int mode, const TQString& cmdArgs, bool skipPasswd)
bool KGPGFile::startProcess(const TQStringList& args)
{
- // now start the KProcess with GPG
+ // now start the TDEProcess with GPG
m_process = new KShellProcess();
*m_process << "gpg";
@@ -265,7 +265,7 @@ void KGPGFile::close(void)
return;
}
- // finish the KProcess and clean up things
+ // finish the TDEProcess and clean up things
if(m_process) {
if(isWritable()) {